@@ -1,3 +1,4 @@
+from json import tool
 from PySide2.QtWidgets import QWidget
 from SciDataTool.Functions import parser
 from PySide2.QtCore import Qt
@@ -101,7 +102,8 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         plot_arg_dict : dict
             Dictionnary with arguments that must be given to the plot
         frozen_type : int
-            0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them, 3 to freeze both axes and operations, 4 to freeze fft
+            0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them,
+            3 to freeze both axes and operations, 4 to freeze fft, 5 to only allow switch
         save_path : str
             path to the folder where the animations are saved
         logger : logger
@@ -215,9 +217,20 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             text_box = TEXT_BOX
         # Set plot layout
         self.canvas = FigureCanvas(fig)
-        self.toolbar = NavigationToolbar(self.canvas, self)
+        if self.toolbar is None:
+            toolbar = NavigationToolbar(self.canvas, self)
+        else:
+            toolbar = NavigationToolbar(self.canvas, self)
+            action_names = [action.text() for action in self.toolbar.actions()]
+            for action in toolbar.actions():
+                if action.text() in action_names:
+                    action.setIcon(
+                        self.toolbar.actions()[action_names.index(action.text())].icon()
+                    )
+                else:
+                    toolbar.removeAction(action)
 
-        self.plot_layout.addWidget(self.toolbar)
+        self.plot_layout.addWidget(toolbar)
         self.plot_layout.addWidget(self.canvas)
 
         self.text = None
@@ -507,6 +520,10 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 widgetToRemove.deleteLater()
 
         if self.fig.get_axes():
+            if len(self.fig.canvas.toolbar.actions()) == 11:
+                self.toolbar = None
+            else:
+                self.toolbar = self.fig.canvas.toolbar
             self.fig.clear()
 
         (self.fig, self.ax, _, _) = init_fig()
