@@ -66,11 +66,15 @@ class WAxisManager(Ui_WAxisManager, QWidget):
         self : WAxisManager
             a WAxisManager object
         """
+        self.blockSignals(True)
         # Making sure that when axis 1 is updated, axis 1 and 2 are both on "None" for the action combobox
-        self.fft_sync("axis 1")
+        self.fft_sync("axis 1", is_refresh=False)
 
         # Recovering the axis selected by the user removing it from the the second axis combobox
         self.w_axis_2.remove_axis(self.w_axis_1.get_axis_selected())
+        self.gen_slice_op(is_refresh=False)
+        self.blockSignals(False)
+        self.update_needed()
 
     def axis_2_updated(self):
         """Method that make sure that when axis 2 is selected (None->?) it has the same fft/ifft combobox selected as axis1
@@ -81,9 +85,12 @@ class WAxisManager(Ui_WAxisManager, QWidget):
             a WAxisManager object
         """
         # Making sure that when axis 1 is updated, axis 1 and 2 are both on "None" for the action combobox
-        self.fft_sync("axis 1")
+        self.blockSignals(True)
+        self.fft_sync("axis 1", is_refresh=False)
+        self.blockSignals(False)
+        self.update_needed()
 
-    def gen_slice_op(self, axes_request_list=None):
+    def gen_slice_op(self, axes_request_list=None, is_refresh=True):
         """Method that gen the right WDataExtrator widget according to the axis selected by the user in the UI
         Parameters
         ----------
@@ -156,7 +163,8 @@ class WAxisManager(Ui_WAxisManager, QWidget):
         else:
             self.w_slice_op = list()
             self.g_data_extract.hide()
-        self.update_needed()
+        if is_refresh:
+            self.update_needed()
 
     def gen_animate(self):
         """Methods called after clicking on animate button to generate a gif on the axis selected and display it
@@ -224,7 +232,7 @@ class WAxisManager(Ui_WAxisManager, QWidget):
 
         return operations_selected
 
-    def fft_sync(self, axis_changed):
+    def fft_sync(self, axis_changed, is_refresh=True):
         """Method that will check the action chosen and that update the other action combobox to have the same action.
         So that, by default, we have FFT and FFT or "None" and "None"
         Parameters
@@ -233,10 +241,11 @@ class WAxisManager(Ui_WAxisManager, QWidget):
             a WAxisManager object
 
         """
-        if axis_changed == "axis 1" and "FFT" in [
-            self.w_axis_1.c_action.itemText(i)
-            for i in range(self.w_axis_1.c_action.count())
-        ]:
+        self.blockSignals(True)
+        if axis_changed == "axis 1":  # and "FFT" in [
+            #     self.w_axis_1.c_action.itemText(i)
+            #     for i in range(self.w_axis_1.c_action.count())
+            # ]:
             action_selected = self.w_axis_1.get_current_action_name()
             self.w_axis_2.set_action(action_selected)
             if action_selected == "FFT":
@@ -287,14 +296,16 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                                 fft_dict[self.w_axis_2.axis_selected]
                             )
                         ] = self.w_axis_2.axis_selected
-            self.gen_slice_op()
-            self.w_axis_1.set_unit()
-            self.w_axis_2.set_unit()
+                # Make sure that all axes are reset to ifft
+                for i, axis in enumerate(self.w_axis_1.axes_list):
+                    if axis in ifft_dict:
+                        self.w_axis_1.axes_list[i] = ifft_dict[axis]
+            self.gen_slice_op(is_refresh=False)
 
-        elif axis_changed == "axis 2" and "FFT" in [
-            self.w_axis_2.c_action.itemText(i)
-            for i in range(self.w_axis_2.c_action.count())
-        ]:
+        elif axis_changed == "axis 2":  # and "FFT" in [
+            #     self.w_axis_2.c_action.itemText(i)
+            #     for i in range(self.w_axis_2.c_action.count())
+            # ]:
             action_selected = self.w_axis_2.get_current_action_name()
             self.w_axis_1.set_action(action_selected)
             if action_selected == "FFT":
@@ -345,9 +356,16 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                                 fft_dict[self.w_axis_1.axis_selected]
                             )
                         ] = self.w_axis_1.axis_selected
-            self.gen_slice_op()
-            self.w_axis_1.set_unit()
-            self.w_axis_2.set_unit()
+                # Make sure that all axes are reset to ifft
+                for i, axis in enumerate(self.w_axis_2.axes_list):
+                    if axis in ifft_dict:
+                        self.w_axis_2.axes_list[i] = ifft_dict[axis]
+            self.gen_slice_op(is_refresh=False)
+        self.w_axis_1.set_unit()
+        self.w_axis_2.set_unit()
+        self.blockSignals(False)
+        if is_refresh:
+            self.update_needed()
 
     def set_axis_widgets(
         self,
@@ -449,7 +467,7 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                     self.w_axis_2.set_axis(axes_list[1])
 
                 # Making sure that we have the same fft/ifft selected for both axis
-                self.axis_2_updated()
+                # self.axis_2_updated()
 
                 # Generating DataSelection with the input of user if they are given or by default (like in a manual plot)
                 if len(slices_op_list) != 0:
@@ -542,5 +560,5 @@ class WAxisManager(Ui_WAxisManager, QWidget):
             a WAxisManager object
         """
 
-        self.refreshNeeded.emit()
         self.refreshRange.emit()
+        self.refreshNeeded.emit()
